@@ -8,10 +8,15 @@ class ScpArticle(Article):
 
     **Attributes**
         page_source :class:`str` — The SCP's text.
-        number :class:`int` — The SCP's number.
+
+        number :class:`str` — The SCP's number. Also works for Joke SCPs.
+
         branch :class:`Branch` — The SCP's original branch.
+
         language :class:`Language` — The fetched SCP's language.
+
         is_joke :class:`boolean` — Whether the SCP has a -J flag.
+
         full_code :class:`str` — The SCP's full code (``"SCP-XXXX-LANG-J"``).
     """
 
@@ -21,7 +26,7 @@ class ScpArticle(Article):
         self.page_source = data["page_source"]
         self.is_joke = "joke" in self.tags
         self.full_code = data["full_code"]
-        self.number = int(re.search(r"(\d+)", self.full_code).group(1))
+        self.number = re.search(r"SCP-([^-]+)", self.full_code).group(1)
         self.language = data["language"]
         self.branch = data["branch"]
 
